@@ -1,5 +1,7 @@
 # 开放平台接口基类
 import requests
+from requests_toolbelt.multipart.encoder import MultipartEncoder
+import json
 
 
 def request_accesstoken(acc: str, pwd: str) -> str:
@@ -21,30 +23,38 @@ class base:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, data=None, method="GET", url=None):
-        host_name = "http://bms.microc.cn/shopguide/api/"
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None):
+        # host_name = "http://bms.microc.cn/shopguide/api/"
         # host_name = "http://test.xxynet.com/shopguide/api/"
+        host_name = "http://bms.chaojidaogou.com/shopguide/api/"
         if not url:
             if host_name not in api_name:
                 url = f"{host_name}{api_name}"
+        condition = {}
 
-        if "accessToken" not in data:
+        if "accessToken" not in params:
             # 没有token自动添加
-            data["accessToken"] = self.token
-        if "appSecret" not in data:
+            params["accessToken"] = self.token
+        if "appSecret" not in params:
             # 没有token自动添加
-            data["appSecret"] = self.app_secret
+            params["appSecret"] = self.app_secret
+        if params:
+            condition["params"] = params
+        if data:
+            condition["data"] = data
+        if json:
+            condition["json"] = json
+        if headers:
+            condition["headers"] = headers
 
         if method == "GET":
-            response = requests.get(url, params=data)
+            response = requests.get(url, **condition, timeout=10)
         elif method == "POST":
-            response = requests.get(url, data=data)
+            response = requests.post(url, **condition, timeout=10)
         else:
             raise ValueError("请求方法错误。")
-
         if response.status_code == 200:
-            # print(data,response.json())
             return self.response(response.json())
 
     def response(self, response_raw):
-        return response_raw
\ No newline at end of file
+        return response_raw
