@@ -11,9 +11,9 @@ class cjdgUser(base):
         api_name = "user/create"
         return self.request(api_name, data)
 
-    def createBatch(self, data):
+    def createBatch(self, **data):
         api_name = "user/batchcreate"
-        return self.request(api_name, data)
+        return self.request(api_name, **data)
 
     def list(self, data):
         api_name = "user/query"
@@ -21,6 +21,10 @@ class cjdgUser(base):
 
     def read(self, account):
         api_name = "user/query"
+        data = {
+            "accounts": account,
+        }
+
         return self.request(api_name, data)
 
     def getUserIds(self, accounts):
@@ -28,15 +32,15 @@ class cjdgUser(base):
         data = {
             "accounts": accounts,
         }
-        return self.request(api_name, data, method="POST")
+        return self.request(api_name, data=data, method="POST")
 
     def update(self, data):
         api_name = "user/modifi"
         return self.request(api_name, data)
 
-    def updateBatch(self, data):
-        api_name = "user/modifi"
-        return self.request(api_name, data)
+    def updateBatch(self, **data):
+        api_name = "user/batchmodifi"
+        return self.request(api_name, **data)
 
     def delete(self, data):
         api_name = "user/destroy"
